@@ -9,31 +9,33 @@ sub new {
     my ( $class, $session ) = @_;
     my $self;
 
-    $self->{cache} = Redis->new( %{$session} );
-    print STDERR Dumper(\@_);use Data::Dumper;
+    $self->{cache} = Redis->new( %{ $session->{args} } );
 
     bless $self, $class;
 }
 
 sub insert {
     my ( $self, $session ) = @_;
-    $self->{cache}->set($session->{data}->{_session_id},$session->{serialized});
+    $self->{cache}
+      ->set( $session->{data}->{_session_id}, $session->{serialized} );
 }
 
 *update = *insert;
 
 sub materialize {
     my ( $self, $session ) = @_;
-    $self->{cache}->get($session->{data}->{_session_id}) or die 'Object does not exist in data store.';
+    $self->{cache}->get( $session->{data}->{_session_id} )
+      or die 'Object does not exist in data store.';
 }
 
 sub remove {
     my ( $self, $session ) = @_;
-    $self->{cache}->del($session->{data}->{_session_id});
+    $self->{cache}->del( $session->{data}->{_session_id} );
 }
 
 1;
 __END__
+
 =pod
 
 =head1 NAME
@@ -43,10 +45,8 @@ Apache::Session::Store::NoSQL::Redis - An implementation of Apache::Session::Sto
 =head1 SYNOPSIS
 
  use Apache::Session::NoSQL;
-
- #if you want Apache::Session to open new DB handles:
-
- tie %hash, 'Apache::Session::MySQL', $id, {
+ 
+ tie %hash, 'Apache::Session::NoSQL', $id, {
     Driver => 'Redis',
     # optional: default to localhost
     server => '127.0.0.1:6379',
